==> qore-0.8.11.1.tar.bz2: qore-0.8.11.1/include/qore/intern/config.h <==
/* -*- mode: c++; indent-tabs-mode: nil -*- */
/*
  config.h

  Qore Programming Language

  Copyright (C) 2005 - 2014 David Nichols

  Permission is hereby granted, free of charge, to any person obtaining a
  copy of this software and associated documentation files (the "Software"),
  to deal in the Software without restriction, including without limitation
  the rights to use, copy, modify, merge, publish, distribute, sublicense,
  and/or sell copies of the Software, and to permit persons to whom the
  Software is furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  DEALINGS IN THE SOFTWARE.

  Note that the Qore library is released under a choice of three open-source
  licenses: MIT (as above), LGPL 2+, or GPL 2+; see README-LICENSE for more
  information.
*/

#ifndef QORE_CONFIG_H

#define QORE_CONFIG_H

#ifdef __CYGWIN__
#define __int64 long long
#endif

#ifdef HAVE_UNIX_CONFIG_H
#include <qore/intern/unix-config.h>
#else
#if defined(_WIN32) && !defined(__CYGWIN__)
#include <qore/intern/win32-config.h>
#else
#error no configuration file for this build
#endif
#endif

#endif

==> qore-0.8.12.2.tar.bz2: qore-0.8.12.2/include/qore/intern/config.h <==
/* -*- mode: c++; indent-tabs-mode: nil -*- */
/*
  config.h

  Qore Programming Language

  Copyright (C) 2005 - 2015 David Nichols

  Permission is hereby granted, free of charge, to any person obtaining a
  copy of this software and associated documentation files (the "Software"),
  to deal in the Software without restriction, including without limitation
  the rights to use, copy, modify, merge, publish, distribute, sublicense,
  and/or sell copies of the Software, and to permit persons to whom the
  Software is furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  DEALINGS IN THE SOFTWARE.

  Note that the Qore library is released under a choice of three open-source
  licenses: MIT (as above), LGPL 2+, or GPL 2+; see README-LICENSE for more
  information.
*/

#ifndef QORE_CONFIG_H

#define QORE_CONFIG_H

#ifdef __CYGWIN__
#define __int64 long long
#endif

#ifdef HAVE_UNIX_CONFIG_H
#include "unix-config.h"
#else
#if defined(_WIN32) && !defined(__CYGWIN__)
#include "win32-config.h"
#else
#error no configuration file for this build
#endif
#endif

#endif
